@@ -7,7 +7,7 @@ error() {
 
 # set -x
 
-autoheader || error "could not re-generate config/axiom-c-macros.h"
+autoheader || error "could not re-generate config/fricas_c_macros.h"
 autoconf || error "could not re-generate configure"
 
 # set +x
