@@ -32,7 +32,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 
 #define _MAIN3D_C
-#include "axiom-c-macros.h"
+#include "fricas_c_macros.h"
 #include <string.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -52,14 +52,11 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "XShade.H1"
 #include "all_3d.H1"
 
-#include "spadBitmap.bitmap"
-#include "spadMask.mask"
-
 viewPoints      *viewport;
 GCptr           GChead=NULL;    /* ptr to head of ps GC linked list */
 char            *PSfilename;    /* output file name used in user directory */
 int             psInit=no;      /* need to call globaInitPs() each run */
-char            *envAXIOM;      /* used for ps file paths */
+char            * env_fricas;   /* used for ps file paths */
 int             maxGreyShade=0;
 GC              globalGC1, globalGC2, anotherGC, globGC, trashGC,
                 controlMessageGC, lightingGC, volumeGC, quitGC, processGC,
@@ -115,12 +112,12 @@ int             someInt;
 
 int             drawMore;
 
-int             spadMode=no,            /* yes if receiving AXIOM command and
+int             spadMode=no,            /* yes if receiving FriCAS command and
                                            calling drawViewport */
                 spadDraw=no;            /* yes if drawing viewport for
-                                           an AXIOM command */
+                                           a FriCAS command */
 int             spadSignalReceived=0;  /* yes if current state is a result of
-                                           a signal from AXIOM */
+                                           a signal from FriCAS */
 int             inNextEvent=no;         /* true just before a call to
                                            XNextEvent */
 jmp_buf         jumpFlag;
@@ -194,15 +191,15 @@ int             finishedList=no, zoomed=yes, translated = yes,
                 gotToggle = no;
 poly            *quickList;
 
-                /** if not connected to AXIOM **/
+                /* if not connected to FriCAS */
 int             viewAloned;
 
                 /** for drawing the box **/
 viewTriple      corners[8], clipCorners[8];
 boxSideStruct   box[6], clipBox[6];
 
-                /** for freeing up points created frrom split polygons **/
-int             resMax=0;  /* number of points in the split point resevoir */
+                /** for freeing up points created from split polygons **/
+int             resMax=0;  /* number of points in the split point reservoir */
 
                 /** view volume stuff **/
 Window          volumeWindow;
@@ -275,7 +272,7 @@ main(void)
   /**** link Xwindows to viewports - X10 feature ****/
   table = XCreateAssocTable(nbuckets);
 
-  /**** Create AXIOM color map ****/
+  /**** Create FriCAS color map ****/
   totalShades = 0;
   totalColors = XInitSpadFill(dsply,scrn,&colorMap,
                               &totalHues,&totalSolidShades,
@@ -504,12 +501,6 @@ main(void)
   /* Initialize the translation matrix. */
   TRANSLATE(-viewport->deltaX,-viewport->deltaY,0.0,T);
            /**** make the windows for the viewport ****/
-  spadbits = XCreateBitmapFromData(dsply,rtWindow,
-                                   spadBitmap_bits,
-                                   spadBitmap_width,spadBitmap_height);
-  spadmask = XCreateBitmapFromData(dsply,rtWindow,
-                                   spadMask_bits,
-                                   spadMask_width,spadMask_height);
   viewAttrib.background_pixel = backgroundColor;
   viewAttrib.border_pixel = foregroundColor;
 
@@ -524,8 +515,6 @@ main(void)
 */
   XQueryColor(dsply,colorMap,&foreColor);
   XQueryColor(dsply,colorMap,&backColor);
-  viewAttrib.cursor = XCreatePixmapCursor(dsply,spadbits,spadmask,
-                                          &foreColor,&backColor,spadBitmap_x_hot,spadBitmap_y_hot);
   viewAttrib.event_mask = titleMASK;
   if (viewData.vW) {
     titleSizeHints.flags  = PPosition | PSize;
@@ -591,5 +580,3 @@ main(void)
 
 
 }     /* main() */
-
-
