@@ -217,6 +217,7 @@ funView3D(int viewCommand)
       i1 = strlen(s1);
       code = write(viewport->viewOut,&i1,intSize);
       code = write(viewport->viewOut,s1,i1);
+      free(s1);
       break;
 
     case writeView:
@@ -231,6 +232,7 @@ funView3D(int viewCommand)
         i2 = get_int(spadSock);
         code = write(viewport->viewOut,&i2,intSize);
       }
+      free(s1);
       break;
 
     case diagOnOff:
@@ -308,11 +310,11 @@ forkView3D(int typeOfViewport)
 #ifdef DEBUG
     fprintf(stderr,"Executing ThreeDimensionalViewport process\n");
 #endif
-    env_fricas = getenv("AXIOM");
+    env_fricas = getenv("FRICAS");
     {
         size_t env_fricas_len = strlen(env_fricas);
         if (env_fricas_len > 20000) {
-            fprintf(stderr, "AXIOM env var too long\n");
+            fprintf(stderr, "FRICAS env var too long\n");
             exit(-1);
         }
         run_view = malloc(env_fricas_len + strlen("/lib/view3D") + 1);
@@ -405,7 +407,7 @@ forkView3D(int typeOfViewport)
 
          /*** get acknowledge from viewport */
     code = readViewport(viewport,&(viewport->viewWindow),sizeof(Window));
-    sleep(1);  /* wait a second...*/
+    fricas_sleep(50);
     send_int(spadSock,viewport->PID);  /* acknowledge to spad */
 
   }   /* switch */
