@@ -41,9 +41,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define _GROUP_C
 #include "debug.h"
 
-
-#include "group.h"
-#include "initx.h"
+#include "hyper.h"
 
 #include "all_hyper_proto.H1"
 
@@ -142,7 +140,7 @@ void
 bf_top_group(void)
 {
     /*
-     * Just in case the person is tryin a \em without a grouping
+     * Just in case the person is trying a \em without a grouping
      */
 
     if (! gTopOfGroupStack->next)
