@@ -33,14 +33,6 @@
 
 (setq |$printTimeIfTrue| nil)
 
-(setq |nullstream| '|nullstream|)
-(setq |nonnullstream| '|nonnullstream|)
-(setq *print-escape* nil) ;; so stringimage doesn't escape idents?
-
-;;; FIXME: do we need this?
-#+(and :GCL :IEEE-FLOATING-POINT)
-  (setq system:*print-nans* T)
-
 ;;; In case 'setvart.boot' does not work...
 (setq |$algebraOutputStream| (|mkOutputConsoleStream|))
 
@@ -49,57 +41,31 @@
 
 (setq |$localVars| ())  ;checked by isType
 
-;; For the browser, used for building local databases when a user compiles
-;; their own code.
-(SETQ |$newConstructorList| nil)
-(SETQ |$newConlist| nil)
-(SETQ |$createLocalLibDb| nil)
-
 
 ;; These were originally in SPAD LISP
 
-(setq |$interpOnly| nil)
-(SETQ |$testingSystem| NIL)
-(SETQ |$permitWhere| NIL)
-(DEFPARAMETER |$bootStrapMode| NIL) ;; if true skip functor bodies
-(SETQ |$bootstrapDomains| NIL)
-(SETQ |$compileDontDefineFunctions| 'T)
-(SETQ |$devaluateList| NIL)
-(SETQ |$doNotCompressHashTableIfTrue| T)
 (SETQ |$mutableDomains| NIL)     ; checked in DEFINE BOOT
 (SETQ |$maxSignatureLineNumber| 0)
 (SETQ |$functionLocations| NIL)
-(SETQ |$functorLocalParameters| NIL) ; used in compSymbol
-(SETQ |$insideCategoryPackageIfTrue| NIL)
-(SETQ |$insideCompileBodyIfTrue| NIL)
 (SETQ |$globalExposureGroupAlist| NIL)
 (SETQ |$localExposureDataDefault|
   (VECTOR (LIST '|basic| '|categories|) NIL NIL))
 (SETQ |$localExposureData|
   (VECTOR (LIST '|basic| '|categories|) NIL NIL))
 (setq |$ReadingFile| NIL)
+;; Used by Spad stream machinery
 (setq |$NonNullStream| "NonNullStream")
 (setq |$NullStream| "NullStream")
 (setq |$UninitializedStream| "UninitializedStream")
-(setq |$domPvar| nil)
-(defvar $dalymode nil "if true then leading paren implies lisp cmd")
+
 (setq |$Newline| #\Newline)
 
 
 (SETQ $SPAD_ERRORS (VECTOR 0 0 0))
-(SETQ |$edit_file| NIL)
 (DEFPARAMETER |$InteractiveMode| T)
 
 (SETQ |$ruleSetsInitialized| NIL)
 
-(SETQ |$returnNowhereFromGoGet| NIL)
-
-(SETQ |$insideCanCoerceFrom| NIL)
-
-(SETQ |$useCoerceOrCroak| T)
-
-(SETQ |$abbreviateJoin| NIL)
-
 (SETQ |$InterpreterMacroAlist|
       '((|%i| . (|complex| 0 1))
         (|%e| . (|exp| 1))
@@ -110,11 +76,13 @@
         (|%minusInfinity| . (|minusInfinity|))))
 
 ;; Common lisp control variables
-;;(setq *load-verbose* nil)
 (setq *print-array* nil)
 (setq *print-pretty* t)
 (setq *print-circle* nil)
-
+(setq *print-escape* nil) ;; so stringimage doesn't escape idents
+;;; FIXME: do we need this?
+#+(and :GCL :IEEE-FLOATING-POINT)
+  (setq system:*print-nans* T)
 
 (SETQ |$systemCommands| '(
 ;;  COMMAND              USER LEVEL   - )set userlevel
@@ -132,7 +100,6 @@
    (|frame|                          . |interpreter|)
    (|help|                           . |interpreter|)
    (|history|                        . |interpreter|)
-;; (|input|                          . |interpreter|)
    (|lisp|                           . |development|)
    (|library|                        . |interpreter|)
    (|load|                           . |interpreter|)
@@ -151,6 +118,7 @@
    (|trace|                          . |interpreter|)
    (|undo|                           . |interpreter|)
    (|what|                           . |interpreter|)
+   (|version|                        . |interpreter|)
  ))
 
 (SETQ |$noParseCommands| '(
@@ -165,6 +133,7 @@
     |suspend|
     |synonym|
     |system|
+    |version|
     ))
 
 (SETQ |$tokenCommands| '(
@@ -193,24 +162,8 @@
     |with|
     ))
 
-;; following 2 variables are referenced by PREPARSE1
-
-(defvar |$byConstructors| () "list of constructors to be compiled")
-(defvar |$constructorsSeen| () "list of constructors found")
-
-;; These are for the output routines in OUT BOOT
-
-(SETQ $LINELENGTH 77)
-(DEFPARAMETER $MARGIN 3)
-(DEFCONST BLANK " ")
-(DEFCONST UNDERBAR "_")
-(SETQ |$fortranArrayStartingIndex| 0)
-
 ;; These were originally in INIT LISP
 
-(SETQ |$forceDatabaseUpdate| NIL)  ;; see "load" function
-(DEFPARAMETER |$functorForm| NIL)
-
 (SETQ |$InitialCommandSynonymAlist| '(
        (|?|          . "what commands")
        (|apropos|    . "what things")
@@ -231,9 +184,9 @@
        (|startGraphics|    .  "system $FRICAS/lib/viewman &")
        (|stopGraphics|     .  "lisp (|sockSendSignal| 2 15)")
        (|time|       . "set message time")
+       (|storage|    . "set message storage")
        (|type|       . "set message type")
        (|unexpose|   . "set expose drop constructor")
-       (|version|    . "lisp (concat |$build_version| \" compiled at \" |$build_date|)")
        (|wc|         . "what categories")
        (|wd|         . "what domains")
        (|wp|         . "what packages")
@@ -244,7 +197,6 @@
 
 (DEFPARAMETER |$ConstructorCache| (MAKE_HASHTABLE 'EQ))
 (SETQ |$instantRecord| (MAKE_HASHTABLE 'EQ))
-(SETQ |$immediateDataSymbol| '|--immediateData--|)
 
 (SETQ |$useIntegerSubdomain| 'T)
 
@@ -253,8 +205,6 @@
   (|canCoerce| |hash| EQUAL |count|)
   (|canCoerceFrom| |hash| EQUAL |count|)
   (|coerceConvertMmSelection| |hash| EQUAL |count|)
-; (|getModemapsFromDatabase| |hash| EQUAL |count|)
-; (|getOperationAlistFromLisplib| |hash| EQUAL |count|)
   (|isLegitimateMode| |hash| EQUAL |count|)
   (|isValidType| |hash| EQUAL |count|)
   (|resolveTT|   |hash| EQUAL |count|)
@@ -263,14 +213,11 @@
   (|findRetractMms| |hash| EQUAL |count|)
   (|getConstantFromDomain|  |hash| EQUAL |count|)
   (|interpLookup| |hash| EQUAL |count|)
-;  (|isSubDomain|   |hash| EQUAL |count|)
 ))
 
 ;; the following symbol holds the canonical "failed" value
 (SETQ |$failed| "failed")
 
-(SETQ |$constructorDataTable| NIL)
-
 (SETQ |$univariateDomains| '(
     |UnivariatePolynomial|
     |UnivariateTaylorSeries|
@@ -287,7 +234,7 @@
 (SETQ |$Primitives| '(|Union| |Mapping| |Record| |Enumeration|))
 
 (SETQ |$DomainsWithoutLisplibs| '(
-  CAPSULE |Union| |Record| |SubDomain| |Mapping| |Enumeration| |Domain| |Mode|))
+  CAPSULE |Union| |Record| |SubDomain| |Mapping| |Enumeration| |Mode|))
 
 (SETQ |$letAssoc| NIL)
         ;" used for trace of assignments in SPAD code -- see macro LETT"
@@ -316,7 +263,7 @@
    |UnionCategory|
       ))
 
-(SETQ |$printStorageIfTrue| NIL) ;; storage info disabled in common lisp
+(SETQ |$printStorageIfTrue| NIL)
 (SETQ |$noEnv| NIL)
 
 (SETQ |$SideEffectFreeFunctionList| '(
@@ -336,6 +283,7 @@
 (SETQ |$DoubleFloat| '(|DoubleFloat|))
 
 (SETQ |$Integer| '(|Integer|))
+(SETQ |$SingleInteger| '(|SingleInteger|))
 (SETQ |$ComplexInteger| (LIST '|Complex| |$Integer|))
 (SETQ |$NonNegativeInteger| '(|NonNegativeInteger|))
 (SETQ |$PositiveInteger| '(|PositiveInteger|))
@@ -345,8 +293,6 @@
 (SETQ |$Void|  '(|Void|))
 (SETQ |$QuotientField| '|Fraction|)
 (SETQ |$FunctionalExpression| '|Expression|)
-(SETQ |$DoubleFloat| '(|DoubleFloat|))
-(SETQ |$SingleInteger| '(|SingleInteger|))
 
 (SETQ |$InteractiveFrame| (LIST (LIST NIL)))
 (SETQ |$DomainsInScope| (LIST NIL))
@@ -433,9 +379,6 @@
 (SETQ |$NRTdeltaLength| 0)
 (SETQ |$NRTmonitorIfTrue| NIL)
 
-(SETQ |$useConvertForCoercions| NIL)
-
-
 
 (setq credits '(
 "An alphabetical listing of contributors to AXIOM (to October, 2006):"
