@@ -44,6 +44,10 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "cfuns-c.H1"
 
+#ifdef GCL_SOURCE
+#undef HOST_HAS_DIRFD_FCHDIR
+#endif
+
 /* Most versions of Windows don't have the POSIX functions getuid(),
    geteuid(), getgid(), and getegid().  The following definitions are
    approximations, to patch for the deficiencies of Windows
@@ -65,24 +69,6 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #  define getegid() getgid()
 #endif
 
-int
-addtopath(char *dir)
-{
-    char *path, *newpath;
-
-    path = getenv("PATH");
-    if (path == NULL)
-        return -1;
-
-    newpath = (char *) malloc(1 + strlen(path) + strlen(dir) + strlen("PATH=:"));
-    if (newpath == NULL)
-        return -1;
-
-    sprintf(newpath, "PATH=%s;%s", path, dir); /* MSYS/MinGW ??? */
-
-    return putenv(newpath);
-}
-
 /*
  * Test whether the path is the name of a directory.  Returns 1 if so, 0 if
  * not, -1 if it doesn't exist.
@@ -110,14 +96,14 @@ directoryp(char *path)
 int
 makedir(char *path)
 {
-#ifdef S_IRWXO
+#ifdef HAVE_TWO_ARG_MKDIR
    return ( mkdir (path,(S_IRWXU | S_IRWXO | S_IRWXG)) );
 #else
    return ( mkdir (path) );
 #endif
 }
 
-int
+static int
 make_path_from_file(char *s, char *t)
 {
     char *pos = NULL;
@@ -142,7 +128,7 @@ make_path_from_file(char *s, char *t)
    read access of a file designated by its name.
 
    The access is determined based on the POSIX semantics; see
-   "Advanced Programming in the UNIX Environement", section 4.5.
+   "Advanced Programming in the UNIX Environment", section 4.5.
 
    1. If the effective user ID of the process is 0 (the superuser),
       access is allowed.  This gives the superuser free rein throughout
@@ -163,7 +149,7 @@ make_path_from_file(char *s, char *t)
 
 /* Return
      -1 if the file designated by PATH is inexistent.
-      0 if the file exists but wirte access is denied.
+      0 if the file exists but write access is denied.
       1 if the file exists and process has write access.
       2 if the file does not exists but process has write
         has write access to the dirname of path.  */
@@ -201,64 +187,17 @@ writeablep(char *path)
 }
 
 
-int
-readablep(char *path)
-{
-    struct stat buf;
-    int code;
-
-    code = stat(path, &buf);
-    if (code == -1) {
-        return (-1);
-    }
-    else if (geteuid() == buf.st_uid) {
-        return ((buf.st_mode & S_IREAD) != 0);
-#ifdef S_IRGRP
-    }
-    else if (getegid() == buf.st_gid) {
-        return ((buf.st_mode & S_IRGRP) != 0);
-#endif
-#ifdef S_IROTH
-    }
-    else {
-     return ((buf.st_mode & S_IROTH) != 0);
-#endif
-    };
-    return ( 1 ); /* MSYS/MinGW */
-}
-
-
-long
-findString(char *file, char *string)
-{
-    int nstring, charpos;
-    FILE *fn;
-    char buffer[1024];
-
-    if ((fn = fopen(file, "r")) == NULL)
-        return -1;
-
-    for (charpos = 0, nstring = strlen(string);
-         fgets(buffer, sizeof buffer, fn) != NULL;
-         charpos += strlen(buffer)
-        )
-        if (!strncmp(buffer, string, nstring))
-            return charpos;
-    return -1;
-
-}
-
 #ifdef HOST_HAS_DIRECTORY_OPERATIONS
 
 #include <dirent.h>
 
-char * fricas_copy_string(char *str)
+static char * fricas_copy_string(char *str)
 {
     char * res = malloc(strlen(str) + 1);
     if (res) {
         strcpy(res, str);
     } else {
-        fprintf(stderr, "Malloc failed (fricas_copy_string)\n");
+        perror("Malloc failed (fricas_copy_string)\n");
     }
     return res;
 }
@@ -282,25 +221,25 @@ remove_directory(char * name)
     struct file_list * flst = 0;
 #ifdef HOST_HAS_DIRFD_FCHDIR
     if (!cur_dir) {
-        fprintf(stderr, "Unable to open current directory\n");
+        perror("Unable to open current directory\n");
         return -1;
     }
 #else
     if (name_len > INT_MAX/5) {
-        fprintf(stderr, "directory name too long\n");
+        perror("directory name too long\n");
         return -1;
     }
 #endif
     dir = opendir(name);
     if (!dir) {
-        fprintf(stderr, "Unable to open directory to be removed\n");
+        perror("Unable to open directory to be removed\n");
         goto err1;
     }
 #ifdef HOST_HAS_DIRFD_FCHDIR
     cur_dir_fd = dirfd(cur_dir);
     dir_fd = dirfd(dir);
     if (cur_dir_fd == -1 || dir_fd == -1) {
-        fprintf(stderr, "dirfd failed\n");
+        perror("dirfd failed\n");
         goto err2;
     }
 #endif
@@ -316,7 +255,7 @@ remove_directory(char * name)
         } else {
             struct file_list * npos = malloc(sizeof(*npos));
             if (!npos) {
-                fprintf(stderr, "Malloc failed (npos)\n");
+                perror("Malloc failed (npos)\n");
                 break;
             }
             npos->file = fricas_copy_string(fname);
@@ -349,14 +288,12 @@ remove_directory(char * name)
 #else
         char pathbuf[PATH_MAX];
         if (strlen(flst->file) + name_len + 1 < PATH_MAX) {
-            strcpy(pathbuf, name);
-            strcat(pathbuf, "/");
-            strcat(pathbuf, flst->file);
-            if (unlink(pathbuf)) {
-                perror("Unlink failed");
-            }
+	  snprintf(pathbuf,sizeof(pathbuf),"%s/%s",name,flst->file);
+	  if (unlink(pathbuf)) {
+	    perror("Unlink failed");
+	  }
         } else {
-            fprintf(stderr, "panthname too long\n");
+            perror("pathname too long\n");
         }
 #endif
         free(flst->file);
