@@ -68,15 +68,17 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define MSG_NOSIGNAL 0
 #endif
 
-Sock clients[MaxClients];       /* socket description of spad clients */
-Sock server[2];                 /* AF_LOCAL and AF_INET sockets for server */
-Sock *purpose_table[TotalMaxPurposes]; /* table of dedicated socket types */
-fd_set socket_mask;             /* bit mask of active sockets */
-fd_set server_mask;             /* bit mask of server sockets */
-int socket_closed;              /* used to identify closed socket on SIGPIPE */
-int spad_server_number = -1;    /* spad server number used in sman */
-int str_len = 0;
-int still_reading  = 0;
+STATIC Sock clients[MaxClients];       /* socket description of spad clients */
+STATIC Sock server[2];                 /* AF_LOCAL and AF_INET sockets for server */
+STATIC Sock *purpose_table[TotalMaxPurposes]; /* table of dedicated socket types */
+STATIC fd_set socket_mask;             /* bit mask of active sockets */
+STATIC fd_set server_mask;             /* bit mask of server sockets */
+STATIC int socket_closed;              /* used to identify closed socket on SIGPIPE */
+STATIC int spad_server_number = -1;    /* spad server number used in sman */
+STATIC int str_len = 0;
+#ifndef GCL_SOURCE
+STATIC int still_reading  = 0;
+#endif
 
 
 
@@ -179,7 +181,7 @@ fricas_close_socket(fricas_socket s)
 #endif
 }
 
-/* Return 1 is the last call was cancelled. */
+/* Return 1 if the last call was cancelled. */
 
 static inline int
 fricas_call_was_cancelled(void)
@@ -191,7 +193,7 @@ fricas_call_was_cancelled(void)
 #endif
 }
 
-/* Return 1 is last connect() was refused.  */
+/* Return 1 if last connect() was refused.  */
 
 static inline int
 fricas_connection_refused(void)
@@ -261,7 +263,7 @@ sread(Sock *sock, char *buf, int buf_size, char *msg)
   }
   if (ret_val == -1) {
     if (msg) {
-      sprintf(err_msg, "reading: %s", msg);
+      snprintf(err_msg, sizeof(err_msg),"reading: %s", msg);
       perror(err_msg);
     }
     return -1;
@@ -291,7 +293,7 @@ swrite(Sock *sock,char *buf,int buf_size,char *msg)
       return wait_for_client_write(sock, buf, buf_size, msg);
     } else {
       if (msg) {
-        sprintf(err_msg, "writing: %s", msg);
+        snprintf(err_msg,sizeof(err_msg), "writing: %s", msg);
         perror(err_msg);
       }
       return -1;
@@ -522,12 +524,12 @@ get_string_buf(Sock *sock, char *buf, int buf_len)
     }
 }
 
-char *
+int
 sock_get_string_buf(int purpose, char * buf, int buf_len)
 {
   if (accept_if_needed(purpose) != -1)
-    return get_string_buf(purpose_table[purpose], buf, buf_len);
-  return NULL;
+    return NULL != get_string_buf(purpose_table[purpose], buf, buf_len);
+  return 0;
 }
 
 int
@@ -605,9 +607,8 @@ sock_send_floats(int purpose, double  *vals, int num)
 double
 get_float(Sock *sock)
 {
-  int val;
   double num = -1.0;
-  val = fill_buf(sock, (char *)&num, sizeof(double), "double");
+  fill_buf(sock, (char *)&num, sizeof(double), "double");
 #ifdef DEBUG
   fprintf(stderr,"get_float: received %f\n",num);
 #endif
@@ -759,7 +760,7 @@ connect_to_local_server(char *server_name, int purpose, int time_out)
   uaddr->sun_family = FRICAS_AF_LOCAL;
   strncpy(uaddr->sun_path, name, sizeof(uaddr->sun_path) - 1);
   for(i=0; i<max_con; i++) {
-    code = connect(sock->socket, uaddr, sizeof(*uaddr));
+    code = connect(sock->socket, (struct sockaddr *)uaddr, sizeof(*uaddr));
     if (code == -1) {
       if (
         /* @@@ Why we need this */
@@ -824,8 +825,12 @@ remote_stdio(Sock *sock)
         return;
       else {
         *(buf + len) = '\0';
+#ifdef GCL_SOURCE
+	gcl_puts(buf);
+#else
         fputs(buf, stdout);
         fflush(stdout);
+#endif
       }
     }
   }
@@ -861,7 +866,7 @@ make_server_name(char *name,char * base)
 {
   char *num;
   if (spad_server_number != -1) {
-    sprintf(name, "%s%d", base, spad_server_number);
+    snprintf(name, 256, "%s%d", base, spad_server_number);
     return 0;
   }
   num = getenv("SPADNUM");
@@ -871,7 +876,7 @@ make_server_name(char *name,char * base)
 */
     return -1;
   }
-  sprintf(name, "%s%s", base, num);
+  snprintf(name, 256, "%s%s", base, num);
   return 0;
 }
 
@@ -933,7 +938,7 @@ open_server(char *server_name)
     struct sockaddr_un * uaddr = &(sock->addr.u_addr);
     uaddr->sun_family = FRICAS_AF_LOCAL;
     strncpy(uaddr->sun_path, name, sizeof(uaddr->sun_path) - 1);
-    if (bind(sock->socket, uaddr, sizeof(*uaddr))) {
+    if (bind(sock->socket, (struct sockaddr *)uaddr, sizeof(*uaddr))) {
       perror("binding local server socket");
       server[1].socket = 0;
       return -2;
@@ -1031,15 +1036,15 @@ redirect_stdio(Sock *sock)
 /*  setbuf(stdout, NULL);  */
   fd = dup2(sock->socket, 1);
   if (fd != 1) {
-    fprintf(stderr, "Error connecting stdout to socket\n");
+    perror("Error connecting stdout to socket\n");
     return;
   }
   fd = dup2(sock->socket, 0);
   if (fd != 0) {
-    fprintf(stderr, "Error connecting stdin to socket\n");
+    perror("Error connecting stdin to socket\n");
     return;
   }
-  fprintf(stderr, "Redirected standard IO\n");
+  perror("Redirected standard IO\n");
   FD_CLR(sock->socket, &socket_mask);
 }
 
