@@ -24,6 +24,16 @@
     (is_plus(n nl)
        #-:X8664-TARGET `(eql (the fixnum (ccl::%bignum-sign ,n)) 0)
        #+:X8664-TARGET `(ccl::%bignum-0-or-plusp ,n ,nl))
+    (alloc_bignum (rl res)
+       #+(and :64-BIT-TARGET :CCL-1.12)
+         `(ccl::%maybe-allocate-bignum ,rl ,res)
+       #-(and :64-BIT-TARGET :CCL-1.12)
+         `(ccl::%alloc-misc ,rl (bignum_subtag)))
+    (maybe_call_with_res_2 (f x y)
+       #+(and :64-BIT-TARGET :CCL-1.12)
+         `(,f ,x ,y res)
+       #-(and :64-BIT-TARGET :CCL-1.12)
+         `(,f ,x ,y))
     )
 
 #+:X8632-TARGET
@@ -352,7 +362,7 @@
 
 (defun gmp-bignum-isqrt (x)
   (let* ((xl (digits_to_words (ccl::%bignum-length x)))
-         (rl (ceiling xl 2))
+         (rl (ceiling (+ 1 xl) 2))
          (xlb (words_to_bytes xl))
          (rlb (words_to_bytes rl))
          (rl2 (words_to_digits rl))
@@ -383,16 +393,19 @@
     (setf (symbol-function 'orig-isqrt)
           (symbol-function 'common-lisp:isqrt)))
 
-(defun gmp-multiply-bignums(x y)
+(defun gmp-multiply-bignums(x y &optional res)
   (let ((xl0 (ccl::%bignum-length x))
         (yl0 (ccl::%bignum-length y)))
        (declare (type fixnum xl0 yl0))
   (if (< xl0 30)
-      (return-from gmp-multiply-bignums (orig-multiply-bignums x y)))
+      (return-from gmp-multiply-bignums
+           (maybe_call_with_res_2 orig-multiply-bignums x y)))
   (if (< yl0 30)
-      (return-from gmp-multiply-bignums (orig-multiply-bignums y x)))
+      (return-from gmp-multiply-bignums
+           (maybe_call_with_res_2 orig-multiply-bignums y x)))
   (if (< (+ xl0 yl0) 120)
-      (return-from gmp-multiply-bignums (orig-multiply-bignums x y)))
+      (return-from gmp-multiply-bignums
+            (maybe_call_with_res_2 orig-multiply-bignums x y)))
   (let* ((xl (digits_to_words xl0))
          (yl (digits_to_words yl0))
          (x-plusp nil)
@@ -404,7 +417,7 @@
          (itmp 0)
          (tmp nil)
          (rlb 0)
-         (res (ccl::%alloc-misc rl2 (bignum_subtag))))
+         (res (alloc_bignum rl2 res)))
         (declare (type fixnum xl yl rl rl2 xlb ylb rlb itmp))
         ;;; XXX Does not work
         ;;; (declare (dynamic-extent res))
@@ -443,14 +456,14 @@
          (ccl::%normalize-bignum-2 t res)))))
 
 
-(defun gmp-positive-bignum-gcd(x y)
+(defun gmp-positive-bignum-gcd(x y &optional res)
   (let* ((xl (digits_to_words (ccl::%bignum-length x)))
          (yl (digits_to_words (ccl::%bignum-length y)))
          (rl (if (< xl yl) xl yl))
          (xlb (words_to_bytes xl))
          (ylb (words_to_bytes yl))
-         (rlb (+ xlb ylb))
-         (res nil))
+         (rlb (if (< xlb ylb) xlb ylb))
+        )
         (declare (type fixnum xl yl rl xlb ylb rlb))
         ;;; XXX Does not work
         ;;; (declare (dynamic-extent res))
@@ -464,7 +477,7 @@
                      :address tx :long xl
                      :address ty :long yl
                      :long))
-         (setf res (ccl::%alloc-misc (words_to_digits rl) (bignum_subtag)))
+         (setf res (alloc_bignum (words_to_digits rl) res))
          (gmp-bignum-copy-to-lisp tr res rl)
          (ccl::%normalize-bignum-2 t res))))
 ;;; Tests
@@ -538,7 +551,7 @@
 #+:sbcl
 (defun gmp-bignum-isqrt (x)
   (let* ((len-x (sb-bignum::%bignum-length x))
-         (len-res (ceiling len-x 2))
+         (len-res (ceiling (+ 1 len-x) 2))
          (res (sb-bignum::%allocate-bignum len-res)))
         (declare (type fixnum len-x len-res))
         (sb-sys:with-pinned-objects (x res)
@@ -598,10 +611,10 @@
     (setf *PACKAGE* package))
 )
 
-(defun unistall-gmp-multiplication()
+(defun uninstall-gmp-multiplication()
    (let ((package *PACKAGE*))
     (ccl:SET-DEVELOPMENT-ENVIRONMENT T)
-   (setf (symbol-function 'ccl::multiply-bignums)
+    (setf (symbol-function 'ccl::multiply-bignums)
           (symbol-function 'orig-multiply-bignums))
     (setf (symbol-function 'ccl::bignum-truncate)
           (symbol-function 'orig-bignum-truncate))
@@ -633,14 +646,27 @@
     (setf (symbol-function 'orig-isqrt)
           (symbol-function 'common-lisp:isqrt)))
 
+(defmacro negate_bignum(x)
+    (let ((sym2
+          (find-symbol "NEGATE-BIGNUM-NOT-FULLY-NORMALIZED" "SB-BIGNUM")))
+        (if sym2
+            `(,sym2 ,x)
+            ;;; 'read-from-string' looks silly, but here we want error
+            ;;;  if NEGATE-BIGNUM is absent from SB-BIGNUM
+            (let ((sym1 (read-from-string "SB-BIGNUM::NEGATE-BIGNUM")))
+                 `(,sym1 ,x nil))
+        )
+    )
+)
+
 (defun gmp-multiply-bignums0 (a b)
   ;;; (declare (type bignum-type a b))
   (let* ((a-plusp (sb-bignum::%bignum-0-or-plusp a
                   (sb-bignum::%bignum-length a)))
          (b-plusp (sb-bignum::%bignum-0-or-plusp b
                   (sb-bignum::%bignum-length b)))
-         (a (if a-plusp a (sb-bignum::negate-bignum a)))
-         (b (if b-plusp b (sb-bignum::negate-bignum b)))
+         (a (if a-plusp a (negate_bignum a)))
+         (b (if b-plusp b (negate_bignum b)))
          (len-a (sb-bignum::%bignum-length a))
          (len-b (sb-bignum::%bignum-length b))
          (len-res (+ len-a len-b))
@@ -684,10 +710,10 @@
   (let* (
     (nx (if (sb-bignum::%bignum-0-or-plusp x (sb-bignum::%bignum-length x))
             (sb-bignum::copy-bignum x)
-            (sb-bignum::negate-bignum x nil)))
+            (negate_bignum x)))
     (ny (if (sb-bignum::%bignum-0-or-plusp y (sb-bignum::%bignum-length y))
             (sb-bignum::copy-bignum y)
-            (sb-bignum::negate-bignum y nil)))
+            (negate_bignum y)))
     (xl (sb-bignum::%bignum-length nx))
     (yl (sb-bignum::%bignum-length ny))
     (rl (if (< xl yl) xl yl))
@@ -722,9 +748,9 @@
     (x-plusp (sb-bignum::%bignum-0-or-plusp x (sb-bignum::%bignum-length x)))
     (y-plusp (sb-bignum::%bignum-0-or-plusp y (sb-bignum::%bignum-length y)))
     (nx (if x-plusp x
-           (sb-bignum::negate-bignum x nil)))
+           (negate_bignum x)))
     (ny (if y-plusp y
-           (sb-bignum::negate-bignum y nil)))
+           (negate_bignum y)))
     (len-x (sb-bignum::%bignum-length nx))
     (len-y (sb-bignum::%bignum-length ny))
     (q nil)
@@ -795,10 +821,9 @@
     (sb-ext:unlock-package "COMMON-LISP")
     (setf (symbol-function 'common-lisp:isqrt)
           (symbol-function 'gmp-isqrt))
-    (sb-ext:lock-package "COMMON-LISP")
-)
+    (sb-ext:lock-package "COMMON-LISP"))
 
-(defun unistall-gmp-multiplication()
+(defun uninstall-gmp-multiplication()
     (sb-ext:unlock-package "SB-BIGNUM")
     (setf (symbol-function 'sb-bignum::multiply-bignums)
           (symbol-function 'orig-multiply-bignums))
@@ -806,20 +831,31 @@
           (symbol-function 'orig-bignum-truncate))
     (setf (symbol-function 'sb-bignum::bignum-gcd)
           (symbol-function 'orig-bignum-gcd))
-    (sb-ext:lock-package "SB-BIGNUM"))
+    (sb-ext:lock-package "SB-BIGNUM")
     (sb-ext:unlock-package "COMMON-LISP")
     (setf (symbol-function 'common-lisp:isqrt)
           (symbol-function 'orig-isqrt))
-    (sb-ext:lock-package "COMMON-LISP")
+    (sb-ext:lock-package "COMMON-LISP")))
 
+(defun load-gmp-lib ()
+  (let ((system-gmp-name #+:WIN32 "libgmp-10.dll"
+                         #-:WIN32 "libgmp.so")
+        (bundled-gmp-name #+:WIN32 "/lib/libgmp-10.dll"
+                          #+:DARWIN "/lib/libgmp.10.dylib"
+                          #-(or :WIN32 :DARWIN) nil))
+    (if (ignore-errors (|quiet_load_alien| system-gmp-name) t)
+        t
+        (and bundled-gmp-name
+             (ignore-errors (|quiet_load_alien|
+                 (BOOT::make-absolute-filename bundled-gmp-name)) t))))
 )
 
 (defun init-gmp(wrapper-lib)
     (if (not *gmp-multiplication-initialized*)
-        (if (ignore-errors (|quiet_load_alien| "libgmp.so") t)
+        (if (load-gmp-lib)
             (if (ignore-errors
                     (|quiet_load_alien| wrapper-lib) t)
-                 (install-gmp-multiplication)
-                 (setf *gmp-multiplication-initialized* t)))))
-
+                (progn
+                    (install-gmp-multiplication)
+                    (setf *gmp-multiplication-initialized* t))))))
 )
