@@ -55,7 +55,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "sockio-c.H1"
 #include "openpty.H1"
 
-char *ws_path = "$AXIOM/bin/AXIOMsys";
+char *ws_path = "$FRICAS/bin/FRICASsys";
 int start_clef = 1;                 /* start clef under spad */
 int start_graphics = 1;             /* start the viewman */
 int start_ht = 1;                   /* start hypertex */
@@ -69,12 +69,12 @@ int tpd=0;                      /* to-print-debug information */
 /* definitions of programs which sman can start */
 /************************************************/
 
-char    *GraphicsProgram        = "$AXIOM/lib/viewman";
-char    *HypertexProgram        = "$AXIOM/bin/hypertex -s";
+char    *GraphicsProgram        = "$FRICAS/lib/viewman";
+char    *HypertexProgram        = "$FRICAS/bin/hypertex -s";
 char    *ClefProgram            =
-           "$AXIOM/bin/clef -f $AXIOM/lib/command.list -e ";
-char    *SessionManagerProgram  = "$AXIOM/lib/session";
-char    *SpadClientProgram      = "$AXIOM/lib/spadclient";
+           "$FRICAS/bin/clef -f $FRICAS/lib/command.list -e ";
+char    *SessionManagerProgram  = "$FRICAS/lib/session";
+char    *SpadClientProgram      = "$FRICAS/lib/spadclient";
 char    *PasteFile              = NULL;
 char    *MakeRecordFile         = NULL;
 char    *VerifyRecordFile       = NULL;
@@ -167,7 +167,7 @@ process_arguments(int argc,char ** argv)
     else if (strcmp(argv[arg], "-ws")          == 0)
       ws_path = argv[++arg];
     else if (strcmp(argv[arg], "-comp")        == 0)
-      ws_path = "$AXIOM/etc/images/comp";
+      ws_path = "$FRICAS/etc/images/comp";
     else if (strcmp(argv[arg], "-nox")         == 0)
       {
         use_X = 0;
@@ -183,7 +183,7 @@ process_arguments(int argc,char ** argv)
     else if (strcmp(argv[arg], "-clefprog")    == 0) {
       strcpy(ClefCommandLine,argv[++arg]);
       ClefProgram =
-        strcat(ClefCommandLine, " -f $AXIOM/lib/command.list -e ");
+        strcat(ClefCommandLine, " -f $FRICAS/lib/command.list -e ");
     }
     else if (strcmp(argv[arg], "-sessionprog") == 0)
       SessionManagerProgram = argv[++arg];
@@ -451,14 +451,18 @@ static void
 start_the_spadclient(void)
 {
   char command[256];
+  char *TERM = getenv("FRICASTERM");
+  if (TERM == NULL) {
+      TERM = "xterm";
+  }
   if (start_clef)
     sprintf(command,
-          "xterm -sb -sl 500 -name fricasclient -n FriCAS -T FriCAS -e %s %s",
-          ClefProgram, SpadClientProgram);
+          "%s -sb -sl 500 -name fricasclient -n FriCAS -T FriCAS -e %s %s",
+          TERM, ClefProgram, SpadClientProgram);
   else
     sprintf(command,
-          "xterm -sb -sl 500 -name fricasclient -n FriCAS -T FriCAS -e %s",
-          SpadClientProgram);
+          "%s -sb -sl 500 -name fricasclient -n FriCAS -T FriCAS -e %s",
+          TERM, SpadClientProgram);
   if (tpd == 1)
     fprintf(stderr,"sman:start_the_spadclient: %s\n",command);
   spawn_of_hell(command, NadaDelShitsky);
@@ -525,12 +529,12 @@ fork_FriCAS(void)
     fprintf(stderr, "Can't create a new process \n");
     exit(0);
   case 0:
-    /* Dissasociate from my parents group so all my child processes */
+    /* Disassociate from my parents group so all my child processes */
     /* look at my terminal as the controlling terminal for the      */
     /* group                                                        */
 
     if(setsid() < 0) {
-      perror("Dissassociating from parents group");
+      perror("Disassociating from parents group");
       exit(-1);
     }
 
@@ -564,10 +568,10 @@ fork_FriCAS(void)
       perror("setting the term buffer");
       exit(-1);
     }
-        augmented_ws_path = (char *)malloc(2 * strlen(ws_path) + strlen(eval_code) + strlen(" -- ") + 1);
+    augmented_ws_path = (char *)malloc(2 * strlen(ws_path) + strlen(eval_code) + strlen(" -- ") + strlen(" ") + 1);
     strcpy(augmented_ws_path,ws_path);          /* write the name    */
-    /* Pass '--' to make sure that argument(s) passed to AXIOMsys
-       do not cause trouble from host Lisp (Closure CL would
+    /* Pass '--' to make sure that argument(s) passed to FRICASsys
+       do not cause trouble from host Lisp (Clozure CL would
        treat argument as Lisp kernel name, Clisp signals error
        if it can not recognize the option. */
     strcat(augmented_ws_path," -- ");
@@ -593,7 +597,7 @@ start_the_FriCAS(char **envp)
   server_num = make_server_number();
   clean_up_old_sockets();
   if (server_num == -1) {
-    fprintf(stderr, "could not get an FriCAS server number\n");
+    fprintf(stderr, "could not get a FriCAS server number\n");
     exit(-1);
   }
   if (ptyopen(&ptcNum, &ptsNum, ptcPath, ptsPath) == -1) {
@@ -773,9 +777,10 @@ monitor_children(void)
     }
     switch(proc->death_action) {
     case Die:
+      fricas_sleep(100); /* wait a bit for socket buffer to be processed */
       kill_all_children();
       clean_up_sockets();
-      fricas_sleep(200);
+      fricas_sleep(100);
       exit(0);
     case NadaDelShitsky:
       break;
